NAME

perldelta - what is new for perl v5.43.11

DESCRIPTION

This document describes differences between the 5.43.10 release and the 5.43.11 release.

If you are upgrading from an earlier release such as 5.43.9, first read perl54310delta, which describes differences between 5.43.9 and 5.43.10.

Security

CVE-2026-8376 - Buffer overflow in Perl_study_chunk

Repeated fixed string buffer overflow check counted characters not bytes.

CVE-2026-8376

Modules and Pragmata

Updated Modules and Pragmata

  • Archive::Tar has been upgraded from version 3.04 to 3.10.

  • Encode has been upgraded from version 3.21 to 3.24.

  • Errno has been upgraded from version 1.38 to 1.39.

  • HTTP::Tiny has been upgraded from version 0.092 to 0.094.

  • IO::Compress has been upgraded from version 2.219 to 2.220.

  • IO::Socket::IP has been upgraded from version 0.43 to 0.44.

  • Module::CoreList has been upgraded from version 5.20260420 to 5.20260601.

  • SelfLoader has been upgraded from version 1.28 to 1.29.

  • Socket has been upgraded from version 2.040 to 2.041.

  • Storable has been upgraded from version 3.40 to 3.41.

  • XS::Typemap has been upgraded from version 0.21 to 0.22.

Testing

Tests were added and changed to reflect the other additions and changes in this release.

Acknowledgements

Perl 5.43.11 represents approximately 6 weeks of development since Perl 5.43.10 and contains approximately 3,000 lines of changes across 130 files from 21 authors.

Excluding auto-generated files, documentation and release tools, there were approximately 960 lines of changes to 58 .pm, .t, .c and .h files.

Perl continues to flourish into its fourth decade thanks to a vibrant community of users and developers. The following people are known to have contributed the improvements that became Perl 5.43.11:

Aristotle Pagaltzis, Chris 'BinGOs' Williams, Dagfinn Ilmari Mannsåker, Dan Kogai, Eric Herman, Graham Knop, Harald Jörg, H.Merijn Brand, James E Keenan, Karl Williamson, Leon Timmermans, Paul Evans, Paul Marquess, Philippe Bruhat (BooK), Richard Leach, Robert Rothenberg, Scott Baker, Shirakata Kentaro, Stefan Adams, Tomasz Konojacki, Tony Cook.

The list above is almost certainly incomplete as it is automatically generated from version control history. In particular, it does not include the names of the (very much appreciated) contributors who reported issues to the Perl bug tracker.

Many of the changes included in this version originated in the CPAN modules included in Perl's core. We're grateful to the entire CPAN community for helping Perl to flourish.

For a more complete list of all of Perl's historical contributors, please see the AUTHORS file in the Perl source distribution.

Reporting Bugs

If you find what you think is a bug, you might check the perl bug database at https://github.com/Perl/perl5/issues. There may also be information at https://www.perl.org/, the Perl Home Page.

If you believe you have an unreported bug, please open an issue at https://github.com/Perl/perl5/issues. Be sure to trim your bug down to a tiny but sufficient test case.

If the bug you are reporting has security implications which make it inappropriate to send to a public issue tracker, then see "SECURITY VULNERABILITY CONTACT INFORMATION" in perlsec for details of how to report the issue.

Give Thanks

If you wish to thank the Perl 5 Porters for the work we had done in Perl 5, you can do so by running the perlthanks program:

perlthanks

This will send an email to the Perl 5 Porters list with your show of thanks.

SEE ALSO

The Changes file for an explanation of how to view exhaustive details on what changed.

The INSTALL file for how to build Perl.

The README file for general stuff.

The Artistic and Copying files for copyright information.